HumanGEMlib is a Python library to perform genome-scale analysis on HumanGEM. Tested in Jupyter Notebook. 

See usage.ipynb on [GitHub](https://github.com/matrixdex/diabetessubtype).

```bash
pip install humangemlib
```

Dependencies:

- cobra==0.29.0
- importlib_resources==6.4.0
- numpy==1.26.4
- pandas==2.2.2
- pyensembl==2.3.13

## License

This project is released under the Creative Commons Zero license. See the [LICENSE](./LICENSE) file for more details.